@@ -7,11 +7,11 @@ dat_list <- list()
 
 # Put the data that you want to analyse with SAS here.
 dat <- data.frame(
-  y = c(449, 413, 326, 409, 358, 291, 341, 278, 312)/12,
-  P = ordered(gl(3, 3)), N = ordered(gl(3, 1, 9))
+  y = npk$yield,
+  P = ordered(gl(3, 24)),
+  N = ordered(gl(3, 1, 24))
 )
 
-
 require(foreign)
 require(here)
 
